@@ -15,21 +15,20 @@ ACTOR_STATES = AttributeDictionary(INITIAL=0X0,
 '''
 .. _actor-states:
 
-Actor States
-~~~~~~~~~~~~~~
-
 Actor state constants are access via::
 
     from pulsar import ACTOR_STATES
-    
-They are:  
+
+They are:
 
 * ``ACTOR_STATES.INITIAL = 0`` when an actor is just created, before the
   :class:`pulsar.Actor.start` method is called.
-* ``ACTOR_STATES.STARTING = 2`` when :class:`pulsar.Actor.start` method is called.
-* ``ACTOR_STATES.RUN = 3`` when :class:`pulsar.Actor.event_loop` is up and running.
-* ``ACTOR_STATES.STOPPING = 4`` when :class:`pulsar.Actor.stop` has been called
-  for the first time and the actor is running.
+* ``ACTOR_STATES.STARTING = 2`` when :class:`pulsar.Actor.start` method
+  is called.
+* ``ACTOR_STATES.RUN = 3`` when :class:`pulsar.Actor.event_loop` is up
+  and running.
+* ``ACTOR_STATES.STOPPING = 4`` when :class:`pulsar.Actor.stop` has been
+  called for the first time and the actor is running.
 '''
 ACTOR_STATES.DESCRIPTION = {ACTOR_STATES.INACTIVE: 'inactive',
                             ACTOR_STATES.INITIAL: 'initial',
@@ -37,14 +36,14 @@ ACTOR_STATES.DESCRIPTION = {ACTOR_STATES.INACTIVE: 'inactive',
                             ACTOR_STATES.RUN: 'running',
                             ACTOR_STATES.STOPPING: 'stopping',
                             ACTOR_STATES.CLOSE: 'closed',
-                            ACTOR_STATES.TERMINATE:'terminated'}
+                            ACTOR_STATES.TERMINATE: 'terminated'}
 SPECIAL_ACTORS = ('monitor', 'arbiter')
 #
 ACTOR_ACTION_TIMEOUT = 5
 '''Important constant used by :class:`pulsar.Monitor` to kill actors which
 don't respond to the ``stop`` command.'''
 
-MAX_ASYNC_WHILE = 1 # Max interval for async_while
+MAX_ASYNC_WHILE = 1     # Max interval for async_while
 MIN_NOTIFY = 3     # DON'T NOTIFY BELOW THIS INTERVAL
 MAX_NOTIFY = 30    # NOTIFY AT LEAST AFTER THESE SECONDS
 ACTOR_TIMEOUT_TOLE = 0.3  # NOTIFY AFTER THIS TIMES THE TIMEOUT
